@@ -99,6 +99,13 @@ class MagicModelSpeed(BaseModel, metaclass=QueryAndBaseMetaClasses):
         new_obj._data_from_db = {} if not from_db else data_from_db
         return new_obj
 
+    def dict(self, *args, **kwargs):
+        d = super().dict(*args, **kwargs)
+        if hasattr(self, "Config") and getattr(self.Config, "extra", None) == "allow":
+            d = self.remove_magic_fields(d)
+            d["id"] = self.id
+        return d
+
     """GETTING AND SETTING FIELDS"""
 
     def set_id(self, id: str, fields_to_exclude: Set[str] = None):
@@ -509,3 +516,51 @@ class MagicModelSpeed(BaseModel, metaclass=QueryAndBaseMetaClasses):
 
         deleted_obj = Deleted(**self.dict(), _key=deleted_key)
         return deleted_obj.save(**kwargs)
+
+    """TRIGGERS"""
+
+    @classmethod
+    def get_triggers(cls) -> list:
+        return getattr(cls.Meta, "triggers", None)
+
+    @staticmethod
+    def get_class_levels(cls: type(MagicModelSpeed), level: int) -> T.List[ClassLevel]:
+        all_subs: T.List[ClassLevel] = []
+
+        for sub in list(cls.__subclasses__()):
+            class_level = ClassLevel(cls=sub, level=level)
+            all_subs.append(class_level)
+            all_subs += MagicModelSpeed.get_class_levels(cls=sub, level=level + 1)
+        return list(set(all_subs))
+
+    @staticmethod
+    def get_trigger_class_from_collection_name(
+        collection_name: str,
+    ) -> type(MagicModelSpeed):
+        class_levels = MagicModelSpeed.get_class_levels(cls=MagicModelSpeed, level=1)
+        matches = []
+        for class_level in class_levels:
+            if (cls := class_level.cls).get_collection_name() == collection_name:
+                if cls.get_triggers():
+                    matches.append(class_level)
+        matches.sort(reverse=True)
+        print("matches", matches)
+        if matches:
+            return max(matches).cls
+
+
+class ClassLevel(BaseModel):
+    cls: type(MagicModelSpeed)
+    level: int
+
+    def __str__(self):
+        return f"{self.cls}{self.level}"
+
+    def __hash__(self):
+        return hash(str(self))
+
+    def __eq__(self, other):
+        return hash(self) == hash(other)
+
+    def __gt__(self, other):
+        return self.level < other.level
